@@ -13,9 +13,9 @@ from Pythonic.elements.binance_sched     import BinanceSched
 from Pythonic.elements.binance_ohlc      import BinanceOHLC
 from Pythonic.elements.binance_order     import BinanceOrder
 from Pythonic.elements.conn_mail         import ConnMail
+from Pythonic.elements.conn_rest         import ConnREST
 
 from Pythonic.elementmaster              import ElementMaster
-from Pythonic.storagebar                 import StorageBar
 from Pythonic.dropbox                    import DropBox
 
 import logging, pickle
@@ -24,6 +24,7 @@ class WorkingArea(QFrame):
 
     func_blocks = {}
     return_grid = pyqtSignal('PyQt_PyObject', name='return_grid')
+    finish_dropbox = pyqtSignal(name='finish_dropbox')
 
     def __init__(self):
         super().__init__()
@@ -44,13 +45,11 @@ class WorkingArea(QFrame):
         #self.mastergrid.setContentsMargins(0, 0, 0, 0)
         #self.mastergrid.setSpacing(0)
 
-        self.storage_bar = StorageBar()
         # grid contains the function blocks
         self.grid = QGridLayout()
         
         self.flow_start = StartElement(0, 0)
         self.grid.addWidget(self.flow_start, 0, 0, Qt.AlignCenter)
-        self.mastergrid.addWidget(self.storage_bar, 0, 1, Qt.AlignRight)
         self.addPlaceholder(1, 0)
 
         # grid is a component of the mastergrid due to display formatting
@@ -109,7 +108,8 @@ class WorkingArea(QFrame):
             logging.debug('WorkingArea::addElement() config: {}'.format(new_type)) 
             #element = new_type
             #element = self.grid.itemAtPosition(row, column).widget()
-            new_type.config = self.storage_bar.returnConfig()
+            new_type.config = self.tmp_config
+            self.finish_dropbox.emit()
             # element was not pickled! 
             # call __getstate__ and __addstate_ to update the function
             # by calling addFunction of the elementmastern 
@@ -151,6 +151,14 @@ class WorkingArea(QFrame):
             self.addPlaceholder(row+1, column+1)
             self.findMissingLinks()
 
+    def receiveConfig(self, config):
+
+        # method is called on mouspress at dropbox->storagebar
+        # parked config is loaded into workingarea instance memory
+
+        logging.debug('WorkingArea::receiveConfig() called')
+        self.tmp_config = config
+
 
     def destroyElement(self, target):
 
